library(yuima)

## Multi

## True model
diff.coef.matrix <- matrix(c("beta1*x1+beta3", "1", "-1", "beta1*x1+beta3"), 2, 2)
drif.coef.vec <- c("alpha1*x1", "alpha2*x2")
model <- setModel(drift = drif.coef.vec, diffusion = diff.coef.matrix, 
                state.variable = c("x1", "x2"), solve.variable = c("x1", "x2"))
sample <- setSampling(Terminal = 2000^(1/3), n = 2000)
yuima <- setYuima(model = model, sampling = sample)

## Data generate
set.seed(200)
simu <- simulate(yuima, xinit = c(1,1), 
                 true.parameter = list(beta1 = -1, beta3 = 2, alpha1 = -2, alpha2 = -1))
Xt <- simu@data@original.data
#plot(Xt[,1], type="l", ylim=c(min(Xt)-1,max(Xt)+1), ylab="Xt", xlab="t")
#par(new=T)
#plot(Xt[,2], type="l", col="red", ylim=c(min(Xt)-1,max(Xt)+1), ylab="", xlab="")
#legend("topleft", legend=c("X1", "X2"), col=c("black", "red"), lty=c(1,1))

## Candidate diffusion term
cand.diff <- list(matrix(c("beta1*x1+beta2*x2+beta3", "1", "-1", "beta1*x1+beta2*x2+beta3"), 2, 2),
                  matrix(c("beta1*x1+beta2*x2", "1", "-1", "beta1*x1+beta2*x2"), 2, 2),
                  matrix(c("beta1*x1+beta3", "1", "-1", "beta1*x1+beta3"), 2, 2),
                  matrix(c("beta2*x2+beta3", "1", "-1", "beta2*x2+beta3"), 2, 2),
                  matrix(c("beta1*x1", "1", "-1", "beta1*x1"), 2, 2),
                  matrix(c("beta2*x2", "1", "-1", "beta2*x2"), 2, 2),
                  matrix(c("beta3", "1", "-1", "beta3"), 2, 2))
                  
## Candidate drift term
cand.drif <- c("alpha1*x1", "alpha2*x2")

## yuima object for all candidate models
cand.model <- NULL
for(i in 1:length(cand.diff)){
	cand <- setModel(drift = cand.drif, diffusion = cand.diff[[i]], 
                     state.variable = c("x1", "x2"), solve.variable = c("x1", "x2"))
    cand.samp <- setSampling(Terminal = 2000^(1/3), n = 2000)
    cand.yuima <- setYuima(model = cand, sampling = cand.samp)
    cand.model <- c(cand.model, list(cand.yuima))
}

## Parameter settings
init <- list(alpha1 = -1, alpha2 = -1, beta1 = 0.5, beta2 = 0.5, beta3 = 0.5)
low <- list(alpha1 = -3, alpha2 = -3, beta1 = -5, beta2 = -5, beta3 = -5)
upp <- list(alpha1 = -0.001, alpha2 = -0.001, beta1 = 5, beta2 = 5, beta3 = 5)

## Use IC for Model 1
ic <- IC(yuima = cand.model[[1]], data = Xt, start = init, lower = low, upper = upp)

## Use IC and results
paranum <- list(1:5, c(1,2,4,5), c(1,3,4,5), c(2,3,4,5), c(1,4,5), c(2,4,5), c(3,4,5))
results <- matrix(0, 7, 8)
for(i in 1:7){
	ic <- IC(yuima = cand.model[[i]], data = Xt, start = init, lower = low, upper = upp)
	results[i,paranum[[i]]] <- ic$par
	results[i,6:8] <- c(ic$BIC, ic$QBIC, ic$CIC) 
}

colnames(results) <- c("beta1", "beta2", "beta3", "alpha1", "alpha2", "BIC", "QBIC", "CIC")
rownames(results) <- c("Model 1", "Model 2", "Model 3", "Model 4", "Model 5", "Model 6", "Model 7")




