library(yuima)

## Single

## True model settings and data generate
set.seed(123)
model <- setModel(drift = "alpha1*x", diffusion = "exp((beta1*sin(x)+beta2)/2)")
sample <- setSampling(Terminal = 1000^(1/3), n = 1000)
yuima <- setYuima(model = model, sampling = sample)
simu <- simulate(yuima, xinit = 1, 
                 true.parameter = list(beta1 = -2, beta2 = 1, alpha1 = -1))
Xt <- simu@data@original.data
#plot(Xt, type="l")

## Model 1
model1 <- setModel(drift = "alpha1*x", diffusion = "exp((beta1*sin(x)+beta2)/2)")
sample1 <- setSampling(Terminal = 1000^(1/3), n = 1000)
yuima1 <- setYuima(model = model1, sampling = sample1)

## Model 2
model2 <- setModel(drift = "alpha1*x", diffusion = "exp(beta1*sin(x)/2)")
sample2 <- setSampling(Terminal = 1000^(1/3), n = 1000)
yuima2 <- setYuima(model = model2, sampling = sample2)

## Parameter settings
init <- list(alpha1 = -0.5, beta1 = 0.5, beta2 = 0.5)
low <- list(alpha1 = -5, beta1 = -5, beta2 = -5)
upp <- list(alpha1 = -0.001, beta1 = 5, beta2 = 5) 

## Use IC
ic1 <- IC(yuima = yuima1, data = Xt, start = init, lower = low, upper = upp)
ic2 <- IC(yuima = yuima2, data = Xt, start = init, lower = low, upper = upp)



